@@ -83,14 +83,19 @@ def readpass():
 	passw=a.split('#')[1]
 	keypass=a.split('#')[2]
 	session=a.split('#')[3]
-
+	port=a.split('#')[4]
+	
 #Open ssh session with expect
-		
-	go = pexpect.spawn("ssh "+host, timeout=60)
+	
+	go = pexpect.spawn("ssh -p "+port+" "+host, timeout=60)
+	
 
-#First ssh return check. authenticity for first ssh session
+	#First ssh return check. authenticity for first ssh session
 
-	a=go.expect(['.*ssword','authenticity'])
+	
+	a=go.expect(['.*ssword','authenticity','.*@'])
+	continuar = "si"
+			
 	
 	if a==0:
 		go.sendline(passw)
@@ -99,34 +104,49 @@ def readpass():
 		go.sendline("yes")
 		go.expect('.*ssword:')
 		go.sendline(passw)
+	
+	else:
 		
+		go.expect (pexpect.EOF)
+		print go.before 
+		go.interact()
+		continuar = "no"
+		
+			
+	
 
 #Send password. We can get 2 responses, another password: if password is wrong
 #or shell prompt. If get another password then password wrong and open password fialog
 #If password is ok, opens session
 
 	
-	i=go.expect(['.*ssword','[#\$] '])
+	if continuar != "no":
+		i=go.expect(['.*ssword','[#\$] '])
 	
-	if i==0:
+		if i==0:
 			
-		print "--Wrong password--"	
-		dialog(host,passw,go,keypass,session)
-		gtk.main()
+			print "--Wrong password--"	
+			dialog(host,passw,go,keypass,session)
+			gtk.main()
 	
 	
-	elif i==1: 
-		print "--Connection established--"
-		go.send("\n")
+		elif i==1: 
+			print "--Connection established--"
+			go.send("\n")
+
+	
 
 #If session send any error, do a sys.exit
 
-	try:
-		go.interact()
-	except:
-		sys.exit()
+		try:
+		
+			go.interact()
+		except:
+			sys.exit()
 
-	sys.exit()
+		sys.exit()
+		
+	print "An error has ocurred. Press ctrl+D to exit."
 #Password dialog
 
 class dialog:
